# SibylSystem-Py

>Python3 wrapper for the Sibyl System antispam API for telegram

## Installation

```
pip install sibylsystem
```

# Usage

```
>>> from SibylSystem import SibylClient
>>> a = SibylClient(host="hosturl", token="your token")
>>> a.get_info(895373440)
```
